==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/PropertyEditorDescriptionObjectDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyEditorDescriptionObjectDescription } from "./PropertyEditorDescriptionObjectDescription";
/**
 * @hidden
 */
var PropertyEditorDescriptionObjectDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PropertyEditorDescriptionObjectDescriptionMetadata, _super);
    function PropertyEditorDescriptionObjectDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PropertyEditorDescriptionObjectDescriptionMetadata.b = function (a) {
        if (PropertyEditorDescriptionObjectDescriptionMetadata.a == null) {
            PropertyEditorDescriptionObjectDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PropertyEditorDescriptionObjectDescriptionMetadata.c(PropertyEditorDescriptionObjectDescriptionMetadata.a);
        }
        if (a.g(PropertyEditorDescriptionObjectDescriptionMetadata.a)) {
            return;
        }
        a.s(PropertyEditorDescriptionObjectDescriptionMetadata.a);
    };
    PropertyEditorDescriptionObjectDescriptionMetadata.c = function (a) {
        a.item("DescriptionType", "String");
        a.item("Properties", "Collection:PropertyEditorPropertyDescription:PropertyEditorPropertyDescriptionCollection:PropertyEditorPropertyDescription");
    };
    PropertyEditorDescriptionObjectDescriptionMetadata.d = function (a) {
        PropertyEditorDescriptionObjectDescriptionMetadata.b(a);
        a.u("PropertyEditorDescriptionObject", function () { return new PropertyEditorDescriptionObjectDescription(); });
        a.t("PropertyEditorDescriptionObject", PropertyEditorDescriptionObjectDescriptionMetadata.a);
    };
    PropertyEditorDescriptionObjectDescriptionMetadata.$t = markType(PropertyEditorDescriptionObjectDescriptionMetadata, 'PropertyEditorDescriptionObjectDescriptionMetadata');
    PropertyEditorDescriptionObjectDescriptionMetadata.a = null;
    return PropertyEditorDescriptionObjectDescriptionMetadata;
}(Base));
export { PropertyEditorDescriptionObjectDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/PropertyEditorDescriptionObjectDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyEditorDescriptionObjectDescription } from "./PropertyEditorDescriptionObjectDescription";
/**
 * @hidden
 */
var PropertyEditorDescriptionObjectDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PropertyEditorDescriptionObjectDescriptionMetadata, _super);
    function PropertyEditorDescriptionObjectDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PropertyEditorDescriptionObjectDescriptionMetadata.b = function (a) {
        if (PropertyEditorDescriptionObjectDescriptionMetadata.a == null) {
            PropertyEditorDescriptionObjectDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PropertyEditorDescriptionObjectDescriptionMetadata.c(PropertyEditorDescriptionObjectDescriptionMetadata.a);
        }
        if (a.j(PropertyEditorDescriptionObjectDescriptionMetadata.a)) {
            return;
        }
        a.y(PropertyEditorDescriptionObjectDescriptionMetadata.a);
    };
    PropertyEditorDescriptionObjectDescriptionMetadata.c = function (a) {
        a.item("DescriptionType", "String");
        a.item("Properties", "Collection:PropertyEditorPropertyDescription:PropertyEditorPropertyDescriptionCollection:PropertyEditorPropertyDescription");
    };
    PropertyEditorDescriptionObjectDescriptionMetadata.d = function (a) {
        PropertyEditorDescriptionObjectDescriptionMetadata.b(a);
        a.aa("PropertyEditorDescriptionObject", function () { return new PropertyEditorDescriptionObjectDescription(); });
        a.z("PropertyEditorDescriptionObject", PropertyEditorDescriptionObjectDescriptionMetadata.a);
    };
    PropertyEditorDescriptionObjectDescriptionMetadata.$t = markType(PropertyEditorDescriptionObjectDescriptionMetadata, 'PropertyEditorDescriptionObjectDescriptionMetadata');
    PropertyEditorDescriptionObjectDescriptionMetadata.a = null;
    return PropertyEditorDescriptionObjectDescriptionMetadata;
}(Base));
export { PropertyEditorDescriptionObjectDescriptionMetadata };
